@@ -15,6 +15,7 @@ from pulpcore.client.pulpcore.api.exporters_pulp_exports_api import ExportersPul
 from pulpcore.client.pulpcore.api.groups_api import GroupsApi
 from pulpcore.client.pulpcore.api.groups_model_permissions_api import GroupsModelPermissionsApi
 from pulpcore.client.pulpcore.api.groups_object_permissions_api import GroupsObjectPermissionsApi
+from pulpcore.client.pulpcore.api.groups_roles_api import GroupsRolesApi
 from pulpcore.client.pulpcore.api.groups_users_api import GroupsUsersApi
 from pulpcore.client.pulpcore.api.importers_pulp_api import ImportersPulpApi
 from pulpcore.client.pulpcore.api.importers_pulp_import_check_api import ImportersPulpImportCheckApi
@@ -26,10 +27,12 @@ from pulpcore.client.pulpcore.api.repair_api import RepairApi
 from pulpcore.client.pulpcore.api.repositories_api import RepositoriesApi
 from pulpcore.client.pulpcore.api.repositories_reclaim_space_api import RepositoriesReclaimSpaceApi
 from pulpcore.client.pulpcore.api.repository_versions_api import RepositoryVersionsApi
+from pulpcore.client.pulpcore.api.roles_api import RolesApi
 from pulpcore.client.pulpcore.api.signing_services_api import SigningServicesApi
 from pulpcore.client.pulpcore.api.status_api import StatusApi
 from pulpcore.client.pulpcore.api.task_groups_api import TaskGroupsApi
 from pulpcore.client.pulpcore.api.tasks_api import TasksApi
 from pulpcore.client.pulpcore.api.uploads_api import UploadsApi
 from pulpcore.client.pulpcore.api.users_api import UsersApi
+from pulpcore.client.pulpcore.api.users_roles_api import UsersRolesApi
 from pulpcore.client.pulpcore.api.workers_api import WorkersApi
